package ch.unige.solidify.util;

public class OSTool {
  public static class OSEnum {
    public static final String OSX = "mac";
    public static final String SOLARIS = "sunos";
    public static final String UNDEFINED = "undefined";
    public static final String UNIX = "uni";
    public static final String UNIX_AIX = "aix";
    public static final String UNIX_NIX = "nix";
    public static final String UNIX_NUX = "nux";
    public static final String WINDOWS = "win";
  }

  private final static String OS_NAME_PROPERTY = "os.name";

  private static String OS = System.getProperty(OS_NAME_PROPERTY).toLowerCase();

  public static String getOS() {
    if (isWindows()) {
      return OSEnum.WINDOWS;
    } else if (isMac()) {
      return OSEnum.OSX;
    } else if (isUnix()) {
      return OSEnum.UNIX;
    } else if (isSolaris()) {
      return OSEnum.SOLARIS;
    } else {
      return OSEnum.UNDEFINED;
    }
  }

  public static boolean isMac() {
    return OS.contains(OSEnum.OSX);
  }

  public static boolean isSolaris() {
    return OS.contains(OSEnum.SOLARIS);
  }

  public static boolean isUnix() {
    return (OS.contains(OSEnum.UNIX_NIX) || OS.contains(OSEnum.UNIX_NUX)
            || OS.contains(OSEnum.UNIX_AIX));
  }

  public static boolean isWindows() {
    return OS.contains(OSEnum.WINDOWS);
  }

}
